#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:message_ordering_enabled, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-EOD
  Forces unicast messages to be processed in order. There are scenarios where JMS may update JNDI very frequently. It will result in a lot of messages over unicast. Due to the close proximity of messages the probability of out of order handling of messages increases which would trigger frequent state dumps. Frequent JNDI tree refresh may result in NameNotFoundException. Use this property to prevent out of order handling of messages. 

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         message_ordering_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:message_ordering_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('MessageOrderingEnabled')
end
