#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  #
  Type.newtype(:wls_coherence_cluster) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
      This resource allows you to manage a coherence cluster in a WebLogic domain.

      Here is an example on how you should use this:

          wls_coherence_cluster { 'WebCoherenceCluster':
            ensure          => 'present',
            clusteringmode  => 'unicast',
            multicastport   => '33389',
            target          => ['WebCluster'],
            targettype      => ['Cluster'],
            unicastport     => '9999',
            storage_enabled =>  '1',
          }

      In this example you are managing a cluster in the default domain. When you want to
      manage a coherence cluster in a specific domain, you can use:

          wls_coherence_cluster { 'my_domain/defaultCoherenceCluster':
            ensure         => 'present',
            clusteringmode => 'unicast',
            multicastport  => '33387',
            unicastport    => '8888',
          }

      Check [the Oracle Weblogic documentation](http://docs.oracle.com/middleware/1221/wls/INTRO/domains.htm#INTRO330)
      for more documentation about setting up and managing a coherence cluster.

    EOD

    bean_type('CoherenceClusterSystemResource')

    ensurable

    parameter :domain
    parameter :name
    parameter :timeout
    parameter :coherence_cluster_name
    parameter :storage_enabled
    property :clusteringmode
    property :unicastaddress
    property :unicastport
    property :multicastaddress
    property :multicastport
    property :target
    property :targettype
    extraproperties do
      property :clustering_mode
      property :multicast_listen_address
      property :multicast_listen_port
      property :security_framework_enabled
      property :time_to_live
      property :transport
      property :unicast_listen_address
      property :unicast_listen_port
      property :unicast_port_auto_adjust
      property :compatibility_name
      property :deployment_order
      property :deployment_principal_name
      property :module_type
      property :notes
      property :report_group_file
      property :source_path
      property :using_custom_cluster_configuration_file
      #
      # Weblogic 12.2.1 new properties
      #
      property :cluster_listen_port
      property :tags
    end

    add_title_attributes(:coherence_cluster_name)
  end
end
