#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_max_unique_name_statistics, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  

  desc <<-EOD
  The maximum number of unique transaction names for which statistics are maintained.  The first 1001 unique transaction names are maintained as their own transaction name and stored in each statistic. After the 1001st transaction name is reached, the transaction name is stored as <code>weblogic.transaction.statistics.namedOverflow</code>, and the transaction statistic is also merged and maintained in <code>weblogic.transaction.statistics.namedOverflow</code>.  A transaction name typically represents a category of business transactions, such as "funds-transfer." 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jta_max_unique_name_statistics => '1000'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jta_max_unique_name_statistics']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JTA/%{domain_name}/MaxUniqueNameStatistics')
end
