#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_security_interop_mode, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-EOD
  Specifies the security mode of the communication channel used for XA calls between servers that participate in a global transaction. All server instances in a domain must have the same security mode setting.  Security Interoperability Mode options: <ul> <li>default  The transaction coordinator makes calls using the kernel identity over an admin channel if it is enabled, and <code>anonymous</code> otherwise. Man-in-the-middle attacks are possible if the admin channel is not enabled.</li>  <li>performance  The transaction coordinator makes calls using <code>anonymous</code> at all times. This implies a security risk since a malicious third party could then try to affect the outcome of transactions using a man-in-the-middle attack.</li>  <li>compatibility  The transaction coordinator makes calls as the kernel identity over an insecure channel. This is a high security risk because a successful man-in-the-middle attack would allow the attacker to gain administrative control over both domains. This setting should only be used when strong network security is in place. </li> </ul> 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jta_security_interop_mode => 'default'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jta_security_interop_mode']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JTA/%{domain_name}/SecurityInteropMode')
end
