#
# See the file "LICENSE" for the full license governing this code.
#
require "#{File.dirname(__FILE__)}/../foreign_server_object_property"

newproperty(:local_jndi_name, :parent => Puppet::Parameter::WlsProperty) do
  extend ForeignServerObjectProperty

  desc <<-EOD
  The name that the remote object will be bound to in the local server's JNDI tree. This is the name that should be used to look up the object on the local server. 

  An example on how to use this:

      wls_foreign_server_object {a_wls_foreign_server_object :
         ...
         local_jndi_name => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_foreign_server_object:local_jndi_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('LocalJNDIName')
end
