#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:client_id_policy, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  The Client ID Policy indicates whether more than one JMS connection can use the same Client ID.  The valid values are: <li><code>CLIENT_ID_POLICY_RESTRICTED</code> - The default. Only one connection that uses this policy can exist in a cluster at any given time for a particular Client ID (if a connection already exists with a given Client ID, attempts to create new connections using this policy with the same Client ID fail with an exception).</li>  <li><code>CLIENT_ID_POLICY_UNRESTRICTED</code>  - Connections created using this policy can specify any Client ID, even when other restricted or unrestricted connections already use the same Client ID. The Unrestricted Client ID capability was added in WebLogic 10.3.4 (11gR1PS3). </li> </ul> Notes: <ul><li>WebLogic JMS applications can override the Client ID Policy specified on the connection factory configuration by casting a <code>javax.jms.Connection</code> instance to <code>weblogic.jms.extension.WLConnection</code> and calling <code>setClientID(String clientID, String clientIDPolicy)</code> or <code>setClientIDPolicy(String clientIDPolicy)</code>.</li> <li>Two connections with the same Client ID are treated as two different independent connections if they have a different Client ID Policy. This means a cluster can host a single Restricted Client ID Policy connection, and also concurrently host multiple Unrestricted Client ID Policy connections that have the same Client ID as the Restricted connection.</li> <li>Two durable subscriptions with the same Client ID and Subscription Name are treated as two different independent subscriptions if they have a different Client ID Policy. Similarly, two Sharable non-durable subscriptions with the same Client Id are treated as two different independent subscriptions if they have a different Client ID Policy.</li> <li>Durable subscriptions created using an Unrestricted  Client Id must be unsubscribed using <code>weblogic.jms.extensions.WLSession.unsubscribe(Topic topic, String name)</code>, instead of <code>javax.jms.Session.unsubscribe(String name)</code>.</li> </ul> This attribute is dynamic and can be changed at any time. However, changing the value does not affect existing connections. It only affects new connections made with this connection factory. 

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         client_id_policy => 'Restricted'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:client_id_policy']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('ClientParams/%{connection_factory_name}/ClientIdPolicy')
end
