#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:client_reconnect_blocking_millis, :parent => Puppet::Parameter::WlsProperty) do
  

  desc <<-EOD
  The maximum length of time, in milliseconds, that any synchronous JMS calls, such as a <code>producer.send()</code>, <code>consumer.receive()</code>, or <code>session.createBrowser()</code>, will block the calling thread before giving up on a JMS client reconnect in progress.   This attribute is effective only if the Reconnect Policy option is set to either Producers or All. A value of 0 will cause synchronous JMS calls to not wait for any reconnect in progress; a value of -1 will cause an infinite wait for a reconnect.  This attribute is dynamic and can be changed at any time. However, changing the value does not affect existing connections. It only affects new connections made with this connection factory. 

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         client_reconnect_blocking_millis => '60000'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:client_reconnect_blocking_millis']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('ClientParams/%{connection_factory_name}/ReconnectBlockingMillis')
end
