#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:override_time_to_deliver, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  The default delay, either in milliseconds or as a schedule, between when a message is produced and when it is made visible on its target destination, regardless of the delivery time specified by the producer and/or connection factory. The default value (<tt>-1</tt>) specifies that the destination will not override the TimeToDeliver setting specified by the producer and/or connection factory. The TimeToDeliver override can be specified either as a long or as a schedule.  Note: Changing the TimeToDeliver override only affects future message delivery, it does not affect message delivery of already produced messages. 

  An example on how to use this:

      wls_jms_template {a_wls_jms_template :
         ...
         override_time_to_deliver => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_template:override_time_to_deliver']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('DeliveryParamsOverrides/%{template_name}/TimeToDeliver')
end
