#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:default_unit_of_order, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-EOD
  Specifies whether WebLogic Server creates a system-generated unit-of-order name based on the domain, JMS server, and destination name. Any message arriving at this destination that does not already belong to a unit-of-order is assigned this default name.  This field is recommended for advanced use. Generally, it is  recommended to set a message unit-of-order using application calls or connection factory configuration. When relying on a destination default unit order to enforce ordering with a distributed destination, the application must be aware that unit-of-order routing doesn't apply. Instead the application must specifically ensure that any particular set of messages that must be processed in order are all sent to the same specific member destination even in the event of process failures or service migration.

  An example on how to use this:

      wls_jms_topic {a_wls_jms_topic :
         ...
         default_unit_of_order => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_topic:default_unit_of_order']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('DefaultUnitOfOrder')
end
