#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:blocking_send_policy, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Determines whether the JMS server delivers smaller messages before larger ones when a destination has exceeded its maximum number of messages. <code>FIFO</code> prevents the JMS server from delivering smaller messages when larger ones are already waiting for space. <code>Preemptive</code> allows smaller send requests to preempt previous larger ones when there is sufficient space for smaller messages on the destination.  This policy is defined only for the JMS server; it cannot be set on individual destinations.  Additional information on the <code>FIFO</code> and <code>Preemptive</code> policies is provided below.  <code>FIFO</code> (first in, first out) indicates that all send requests for the same destination are queued up one behind the other until space is available. No send request is permitted to successfully complete if there is another send request waiting for space before it. When space is limited, the FIFO policy prevents the starvation of larger requests because smaller requests cannot continuously use the remaining available space. Smaller requests are delayed, though not starved, until the larger request can be completed. When space does become available, requests are considered in the order in which they were made. If there is sufficient space for a given request, then that request is completed and the next request is considered. If there is insufficient space for a given request, then no further requests are considered until sufficient space becomes available for the current request to complete.  <code>Preemptive</code> indicates that a send operation can preempt other blocking send operations if space is available. That is, if there is sufficient space for the current request, then that space is used even if there are other requests waiting for space. When space is limited, the Preemptive policy can result in the starvation of larger requests. For example, if there is insufficient available space for a large request, then it is queued up behind other existing requests. When space does become available, all requests are considered in the order in which they were originally made. If there is sufficient space for a given request, then that request is allowed to continue and the next request is considered. If there is insufficient space for a given request, then that request is skipped and the next request is considered. 

  An example on how to use this:

      wls_jmsserver {a_wls_jmsserver :
         ...
         blocking_send_policy => 'FIFO'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jmsserver:blocking_send_policy']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('BlockingSendPolicy')
end
