#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ds_row_prefetch, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Enables multiple rows to be "prefetched" (that is, sent from the server to the client) in one server access.  When an external client accesses a database using JDBC through WebLogic Server, row prefetching improves performance by fetching multiple rows from the server to the client in one server access. WebLogic Server ignores this setting and does not use row prefetching when the client and WebLogic Server are in the same JVM. 

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         ds_row_prefetch => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:ds_row_prefetch']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('JDBCResource/%{multi_datasource_name}/JDBCDataSourceParams/%{multi_datasource_name}/RowPrefetch')
end
