#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_test_table_name, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  The name of the database table to use when testing physical database connections. This name is required when you specify a Test Frequency and enable Test Reserved Connections.  The default SQL code used to test a connection is <code>select count(*) from TestTableName</code> Most database servers optimize this SQL to avoid a table scan, but it is still a good idea to set the Test Table Name to the name of a table that is known to have few rows, or even no rows.  If the Test Table Name begins with <code>SQL</code>, then the rest of the string following that leading token will be taken as a literal SQL statement that will be used to test connections instead of the standard query. For example: <code>SQL BEGIN; Null; END; </code>  For an Oracle database, you can reduce the overhead of connection testing by setting Test Table Name to <code>SQL PINGDATABASE</code> which uses the <code>pingDatabase()</code> method to test the Oracle connection. For any JDBC 4.0 database, it is possible to use "SQL ISVALID" to use the <code>isValid()</code> method on the connection. 

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         pool_test_table_name => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:pool_test_table_name']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JDBCResource/%{multi_datasource_name}/JDBCConnectionPoolParams/%{multi_datasource_name}/TestTableName')
end
