#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:xa_recover_only_once, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Specifies that the transaction manager calls recover on the resource only once. Only applies to data sources that use an XA driver.  Use this setting to work around specific problems with JDBC XA drivers. 

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         xa_recover_only_once => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:xa_recover_only_once']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('JDBCResource/%{multi_datasource_name}/JDBCXAParams/%{multi_datasource_name}/RecoverOnlyOnce')
end
