#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:custom_identity, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
    The custom_identity true or false.

  EOD

  def self.coerce(value)
    Puppet::Pops::Utils.to_n(value)
  end

  newvalues('1', '0')

  maps_to('KeyStores')

  to_translate_to_resource do | raw_resource|
    wls_config = Puppet_X::EnterpriseModules::WebLogic::Tree.new(raw_resource[:domain])
    value = wls_config.get(actual_path(raw_resource))
    (value == "CustomIdentityAndCustomTrust") ? '1' : '0'
  end

  # If custom_identity is '1' The following attributes will also be applied
  # - custom_identity_keystore_passphrase
  # - trust_keystore_passphrase
  # - custom_identity_privatekey_passphrase
  #
  on_apply do
    real_value = value == :"0" ? 'DemoIdentityAndDemoTrust' : 'CustomIdentityAndCustomTrust'
    apply_paths(real_value)
    set_password('CustomIdentityKeyStorePassPhrase', resource[:custom_identity_keystore_passphrase])
    set_password('CustomTrustKeyStorePassPhrase', resource[:trust_keystore_passphrase])
    set_password('SSL/%{server_name}/ServerPrivateKeyPassPhrase', resource[:custom_identity_privatekey_passphrase])
    nil
  end

  def set_password( path_template, value)
    wls_config.set(path_for(path_template), value)
  end
end