#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:outbound_private_key_enabled, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Specifies whether the SSL identity specified by {@link SSLMBean#getServerPrivateKeyAlias() getSSLMBean#ServerPrivateKeyAlias} for this server should be used for outbound SSL connections on the default server channel. In normal circumstances the outbound identity is determined by the caller's environment. 

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         outbound_private_key_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:outbound_private_key_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('OutboundPrivateKeyEnabled')
end
