#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:use_fast_serialization, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Specifies whether to use non-standard object serialization for performance. This option works in different ways for different protocols. In particular under IIOP this option uses Java serialization rather than RMI-IIOP serialization. In general using non-standard serialization is not suitable for interop scenarios and may imply some feature loss. 

  An example on how to use this:

      wls_server_channel {a_wls_server_channel :
         ...
         use_fast_serialization => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_channel:use_fast_serialization']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('UseFastSerialization')
end
