#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_user) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-EOD
    This resource allows you to manage user in an WebLogic Security Realm.

    Here is an example on how you should use this:

        wls_user { 'OracleSystemUser':
          ensure                 => 'present',
          authenticationprovider => 'DefaultAuthenticator',
          description            => 'Oracle application software system user.',
          realm                  => 'myrealm',
        }

    In this example you are managing a user in the default domain. When you want to
    manage a user in a specific domain, you can use:

        # this will use default as wls_setting identifier
        wls_user { 'my_domain/testuser1':
          ensure                 => 'present',
          authenticationprovider => 'DefaultAuthenticator',
          description            => 'testuser1',
          realm                  => 'myrealm',
        }

    EOD

    ensurable

    to_get_raw_resources do
      Puppet.info "index #{name} "
      environment = { 'action' => 'index', 'type' => 'wls_user' }
      wlst template('wls_config/wls_user/index.py.erb', binding), environment
    end

    on_create do
      Puppet.info "create #{name}"
      wlst template('wls_config/wls_user/create.py.erb', binding)
      nil
    end

    on_modify do
      Puppet.info "modify #{name} "
      wlst template('wls_config/wls_user/modify.py.erb', binding)
      nil
    end

    on_destroy do
      Puppet.info "destroy #{name} "
      wlst template('wls_config/wls_user/destroy.py.erb', binding)
      nil
    end

    parameter :domain
    parameter :name
    parameter :user_name
    parameter :password   # TODO: Make this into a manageble property
    parameter :timeout
    property :realm
    property :authenticationprovider
    property :description

    add_title_attributes(:user_name)
  end
end
