#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:log_number_of_files_limited, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Indicates whether to limit the number of log files that this server instance creates to store old messages. (Requires that you specify a file rotation type of <code>SIZE</code> or <code>TIME</code>.)  After the server reaches this limit, it deletes the oldest log file and creates a new log file with the latest suffix.  If you do not enable this option, the server creates new files indefinitely and you must clean up these files as you require. 

  An example on how to use this:

      wls_virtual_host {a_wls_virtual_host :
         ...
         log_number_of_files_limited => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_virtual_host:log_number_of_files_limited']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('WebServerLog/%{virtual_host_name}/NumberOfFilesLimited')
end
